@@ -26,7 +26,7 @@
    59 Bcy, 3161:       PRAISE_BOB and KILL_BOB options split, other minor
                        changes.
 
-   1999-02-22 Arkadiusz Mikiewicz <misiek@pld.ORG.PL>
+   1999-02-22 Arkadiusz Miskiewicz <misiek@pld.ORG.PL>
    - added Native Language Support
 
    2000-03-17 Burt Holzman <bnh@iname.com>
@@ -61,8 +61,9 @@
 #include <string.h>
 #include <time.h>
 #include <stdio.h>
+
 #include "nls.h"
-#include "../defines.h"		/* for util-linux-version */
+#include "c.h"
 
 #ifndef __GNUC__
 #define inline /* foo */
@@ -104,14 +105,14 @@ struct disc_time {
 
 char *excl[] = {
     "Hail Eris!", "All Hail Discordia!", "Kallisti!", "Fnord.", "Or not.",
-    "Wibble.", "Pzat!", "P'tang!", "Frink!", 
+    "Wibble.", "Pzat!", "P'tang!", "Frink!",
 #ifdef PRAISE_BOB
     "Slack!", "Praise \"Bob\"!", "Or kill me.",
 #endif /* PRAISE_BOB */
     /* randomness, from the Net and other places. Feel free to add (after
        checking with the relevant authorities, of course). */
-    "Grudnuk demand sustenance!", "Keep the Lasagna flying!", 
-    "Umlaut Zebra ber alles!", "You are what you see.",
+    "Grudnuk demand sustenance!", "Keep the Lasagna flying!",
+    "You are what you see.",
     "Or is it?", "This statement is false.",
 #if defined(linux) || defined (__linux__) || defined (__linux)
     "Hail Eris, Hack Linux!",
@@ -131,7 +132,7 @@ default_fmt
 #define DY(y) (y+1166)
 
 static inline char *ending(int i) {
-	return (i%10==1)?"st":(i%10==2?"nd":(i%10==3?"rd":"th"));
+	return i/10==1?"th":(i%10==1?"st":(i%10==2?"nd":(i%10==3?"rd":"th")));
 }
 
 static inline int leapp(int i) {
@@ -177,7 +178,7 @@ main (int argc, char *argv[]) {
 	case '-': 
 	    switch(argv[pi][1]) {
 	    case 'V':
-		printf(_("%s from %s\n"), progname, util_linux_version);
+		printf(_("%s (%s)\n"), progname, PACKAGE_STRING);
 	    default: goto usage;
 	    }
 	default: goto thud;
@@ -248,7 +249,8 @@ void format(char *buf, const char* fmt, struct disc_time dt)
     for(i=0; i<fmtlen; i++) {
 	if((i==tib_start) && (dt.day==-1)) {
 	    /* handle St. Tib's Day */
-	    strcpy(bufptr, _("St. Tib's Day")); bufptr += 13;
+	    strcpy(bufptr, _("St. Tib's Day"));
+	    bufptr += strlen(bufptr);
 	    i=tib_end;
 	} else {
 	    if(fmt[i]=='%') {
@@ -266,9 +268,9 @@ void format(char *buf, const char* fmt, struct disc_time dt)
 		case 'N': if(dt.day!=4&&dt.day!=49) goto eschaton; break;
 		case 'n': *(bufptr++)='\n'; break;
 		case 't': *(bufptr++)='\t'; break;
-		    
+
 		case 'Y': sprintf(snarf, "%d", dt.year); wibble=snarf; break;
-		case '.': wibble=sel(excl, sizeof(excl)/sizeof(excl[0]));
+		case '.': wibble=sel(excl, ARRAY_SIZE(excl));
 		    break;
 #ifdef KILL_BOB
 		case 'X': sprintf(snarf, "%d", 
@@ -296,6 +298,7 @@ struct disc_time makeday(int imonth,int iday,int iyear) /*i for input */
     int cal[12] = { 31,28,31,30,31,30,31,31,30,31,30,31 };
     int dayspast=0;
 
+    memset(&funkychickens,0,sizeof(funkychickens));
     /* basic range checks */
     if (imonth < 1 || imonth > 12) {
 	    funkychickens.season = -1;
